#
# PySNMP MIB module INET-ADDRESS-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/INET-ADDRESS-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:04:40 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( ObjectIdentifier, Integer, OctetString, ) = mibBuilder.importSymbols("ASN1", "ObjectIdentifier", "Integer", "OctetString")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ValueSizeConstraint, ConstraintsUnion, SingleValueConstraint, ConstraintsIntersection, ValueRangeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueSizeConstraint", "ConstraintsUnion", "SingleValueConstraint", "ConstraintsIntersection", "ValueRangeConstraint")
( NotificationGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup", "ModuleCompliance")
( MibScalar, MibTable, MibTableRow, MibTableColumn, TimeTicks, mib_2, Counter32, ObjectIdentity, MibIdentifier, iso, IpAddress, Integer32, Unsigned32, NotificationType, Gauge32, Bits, ModuleIdentity, Counter64, ) = mibBuilder.importSymbols("SNMPv2-SMI", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "TimeTicks", "mib-2", "Counter32", "ObjectIdentity", "MibIdentifier", "iso", "IpAddress", "Integer32", "Unsigned32", "NotificationType", "Gauge32", "Bits", "ModuleIdentity", "Counter64")
( DisplayString, TextualConvention, ) = mibBuilder.importSymbols("SNMPv2-TC", "DisplayString", "TextualConvention")
inetAddressMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 76)).setRevisions(("2005-02-04 00:00", "2002-05-09 00:00", "2000-06-08 00:00",))
if mibBuilder.loadTexts: inetAddressMIB.setLastUpdated('200502040000Z')
if mibBuilder.loadTexts: inetAddressMIB.setOrganization('IETF Operations and Management Area')
if mibBuilder.loadTexts: inetAddressMIB.setContactInfo('Juergen Schoenwaelder (Editor)\n         International University Bremen\n         P.O. Box 750 561\n         28725 Bremen, Germany\n\n         Phone: +49 421 200-3587\n         EMail: j.schoenwaelder@iu-bremen.de\n\n         Send comments to <ietfmibs@ops.ietf.org>.')
if mibBuilder.loadTexts: inetAddressMIB.setDescription('This MIB module defines textual conventions for\n         representing Internet addresses.  An Internet\n         address can be an IPv4 address, an IPv6 address,\n         or a DNS domain name.  This module also defines\n         textual conventions for Internet port numbers,\n         autonomous system numbers, and the length of an\n         Internet address prefix.\n\n         Copyright (C) The Internet Society (2005).  This version\n         of this MIB module is part of RFC 4001, see the RFC\n         itself for full legal notices.')
class InetAddressType(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(0, 1, 2, 3, 4, 16,))
    namedValues = NamedValues(("unknown", 0), ("ipv4", 1), ("ipv6", 2), ("ipv4z", 3), ("ipv6z", 4), ("dns", 16),)

class InetAddress(OctetString, TextualConvention):
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(0,255)

class InetAddressIPv4(OctetString, TextualConvention):
    displayHint = '1d.1d.1d.1d'
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(4,4)
    fixedLength = 4

class InetAddressIPv6(OctetString, TextualConvention):
    displayHint = '2x:2x:2x:2x:2x:2x:2x:2x'
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(16,16)
    fixedLength = 16

class InetAddressIPv4z(OctetString, TextualConvention):
    displayHint = '1d.1d.1d.1d%4d'
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(8,8)
    fixedLength = 8

class InetAddressIPv6z(OctetString, TextualConvention):
    displayHint = '2x:2x:2x:2x:2x:2x:2x:2x%4d'
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(20,20)
    fixedLength = 20

class InetAddressDNS(OctetString, TextualConvention):
    displayHint = '255a'
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(1,255)

class InetAddressPrefixLength(Unsigned32, TextualConvention):
    displayHint = 'd'
    subtypeSpec = Unsigned32.subtypeSpec+ValueRangeConstraint(0,2040)

class InetPortNumber(Unsigned32, TextualConvention):
    displayHint = 'd'
    subtypeSpec = Unsigned32.subtypeSpec+ValueRangeConstraint(0,65535)

class InetAutonomousSystemNumber(Unsigned32, TextualConvention):
    displayHint = 'd'

class InetScopeType(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 8, 14,))
    namedValues = NamedValues(("interfaceLocal", 1), ("linkLocal", 2), ("subnetLocal", 3), ("adminLocal", 4), ("siteLocal", 5), ("organizationLocal", 8), ("global", 14),)

class InetZoneIndex(Unsigned32, TextualConvention):
    displayHint = 'd'

class InetVersion(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(0, 1, 2,))
    namedValues = NamedValues(("unknown", 0), ("ipv4", 1), ("ipv6", 2),)

mibBuilder.exportSymbols("INET-ADDRESS-MIB", InetAddressIPv4z=InetAddressIPv4z, InetAddressDNS=InetAddressDNS, InetPortNumber=InetPortNumber, InetAddress=InetAddress, InetAutonomousSystemNumber=InetAutonomousSystemNumber, InetScopeType=InetScopeType, PYSNMP_MODULE_ID=inetAddressMIB, InetAddressIPv4=InetAddressIPv4, InetZoneIndex=InetZoneIndex, InetAddressType=InetAddressType, InetAddressIPv6=InetAddressIPv6, InetAddressPrefixLength=InetAddressPrefixLength, inetAddressMIB=inetAddressMIB, InetAddressIPv6z=InetAddressIPv6z, InetVersion=InetVersion)



#
# PySNMP MIB module PPP-IP-NCP-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/PPP-IP-NCP-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:24:21 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( Integer, ObjectIdentifier, OctetString, ) = mibBuilder.importSymbols("ASN1", "Integer", "ObjectIdentifier", "OctetString")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ValueSizeConstraint, SingleValueConstraint, ConstraintsUnion, ValueRangeConstraint, ConstraintsIntersection, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueSizeConstraint", "SingleValueConstraint", "ConstraintsUnion", "ValueRangeConstraint", "ConstraintsIntersection")
( ifIndex, ) = mibBuilder.importSymbols("IF-MIB", "ifIndex")
( ppp, ) = mibBuilder.importSymbols("PPP-LCP-MIB", "ppp")
( NotificationGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup", "ModuleCompliance")
( TimeTicks, IpAddress, MibScalar, MibTable, MibTableRow, MibTableColumn, Unsigned32, ModuleIdentity, ObjectIdentity, NotificationType, iso, Bits, Gauge32, Counter64, MibIdentifier, Counter32, Integer32, ) = mibBuilder.importSymbols("SNMPv2-SMI", "TimeTicks", "IpAddress", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Unsigned32", "ModuleIdentity", "ObjectIdentity", "NotificationType", "iso", "Bits", "Gauge32", "Counter64", "MibIdentifier", "Counter32", "Integer32")
( TextualConvention, DisplayString, ) = mibBuilder.importSymbols("SNMPv2-TC", "TextualConvention", "DisplayString")
pppIp = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 23, 3))
pppIpTable = MibTable((1, 3, 6, 1, 2, 1, 10, 23, 3, 1), )
if mibBuilder.loadTexts: pppIpTable.setDescription('Table containing the IP parameters and\n                         statistics for the local PPP entity.')
pppIpEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 23, 3, 1, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: pppIpEntry.setDescription('IPCP status information for a particular PPP\n                         link.')
pppIpOperStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 23, 3, 1, 1, 1), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("opened", 1), ("not-opened", 2),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: pppIpOperStatus.setDescription('The operational status of the IP network\n                         protocol. If the value of this object is up\n                         then the finite state machine for the IP\n                         network protocol has reached the Opened state.')
pppIpLocalToRemoteCompressionProtocol = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 23, 3, 1, 1, 2), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("none", 1), ("vj-tcp", 2),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: pppIpLocalToRemoteCompressionProtocol.setDescription('The IP compression protocol that the local\n                         PPP-IP entity uses when sending packets to the\n                         remote PPP-IP entity. The value of this object\n                         is meaningful only when the link has reached\n                         the open state (pppIpOperStatus is opened).')
pppIpRemoteToLocalCompressionProtocol = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 23, 3, 1, 1, 3), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("none", 1), ("vj-tcp", 2),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: pppIpRemoteToLocalCompressionProtocol.setDescription('The IP compression protocol that the remote\n                         PPP-IP entity uses when sending packets to the\n                         local PPP-IP entity. The value of this object\n                         is meaningful only when the link has reached\n                         the open state (pppIpOperStatus is opened).')
pppIpRemoteMaxSlotId = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 23, 3, 1, 1, 4), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,255))).setMaxAccess("readonly")
if mibBuilder.loadTexts: pppIpRemoteMaxSlotId.setDescription('The Max-Slot-Id parameter that the remote node\n                         has advertised and that is in use on the link.\n                         If vj-tcp header compression is not in use on\n                         the link then the value of this object shall be\n                         0. The value of this object is meaningful only\n                         when the link has reached the open state\n                         (pppIpOperStatus is opened).')
pppIpLocalMaxSlotId = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 23, 3, 1, 1, 5), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,255))).setMaxAccess("readonly")
if mibBuilder.loadTexts: pppIpLocalMaxSlotId.setDescription('The Max-Slot-Id parameter that the local node\n                         has advertised and that is in use on the link.\n                         If vj-tcp header compression is not in use on\n                         the link then the value of this object shall be\n                         0. The value of this object is meaningful only\n                         when the link has reached the open state\n                         (pppIpOperStatus is opened).')
pppIpConfigTable = MibTable((1, 3, 6, 1, 2, 1, 10, 23, 3, 2), )
if mibBuilder.loadTexts: pppIpConfigTable.setDescription('Table containing configuration variables for\n                         the IPCP for the local PPP entity.')
pppIpConfigEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 23, 3, 2, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: pppIpConfigEntry.setDescription('IPCP information for a particular PPP link.')
pppIpConfigAdminStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 23, 3, 2, 1, 1), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("open", 1), ("close", 2),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: pppIpConfigAdminStatus.setDescription("The immediate desired status of the IP network\n                         protocol. Setting this object to open will\n                         inject an administrative open event into the IP\n                         network protocol's finite state machine.\n                         Setting this object to close will inject an\n                         administrative close event into the IP network\n                         protocol's finite state machine.")
pppIpConfigCompression = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 23, 3, 2, 1, 2), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("none", 1), ("vj-tcp", 2),)).clone('none')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: pppIpConfigCompression.setDescription('If none(1) then the local node will not\n                         attempt to negotiate any IP Compression option.\n                         Otherwise, the local node will attempt to\n                         negotiate compression mode indicated by the\n                         enumerated value. Changing this object will\n                         have effect when the link is next restarted.')
mibBuilder.exportSymbols("PPP-IP-NCP-MIB", pppIpConfigAdminStatus=pppIpConfigAdminStatus, pppIpRemoteMaxSlotId=pppIpRemoteMaxSlotId, pppIpConfigEntry=pppIpConfigEntry, pppIpLocalMaxSlotId=pppIpLocalMaxSlotId, pppIpEntry=pppIpEntry, pppIpLocalToRemoteCompressionProtocol=pppIpLocalToRemoteCompressionProtocol, pppIpOperStatus=pppIpOperStatus, pppIpTable=pppIpTable, pppIpRemoteToLocalCompressionProtocol=pppIpRemoteToLocalCompressionProtocol, pppIpConfigTable=pppIpConfigTable, pppIp=pppIp, pppIpConfigCompression=pppIpConfigCompression)



#
# PySNMP MIB module MIOX25-MIB (http://pysnmp.sf.net)
# ASN.1 source file:///home/tt/fixed_mibs/MIOX25-MIB
# Produced by pysmi-0.0.2 at Mon Jun 22 22:13:13 2015
# On host cray platform Linux version 2.6.37.6-smp by user tt
# Using Python version 2.7.2 (default, Apr  2 2012, 20:32:47) 
#
( Integer, ObjectIdentifier, OctetString, ) = mibBuilder.importSymbols("ASN1", "Integer", "ObjectIdentifier", "OctetString")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsUnion, SingleValueConstraint, ConstraintsIntersection, ValueSizeConstraint, ValueRangeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsUnion", "SingleValueConstraint", "ConstraintsIntersection", "ValueSizeConstraint", "ValueRangeConstraint")
( ifIndex, ) = mibBuilder.importSymbols("IF-MIB", "ifIndex")
( PositiveInteger, ) = mibBuilder.importSymbols("RFC1253-MIB", "PositiveInteger")
( InstancePointer, ) = mibBuilder.importSymbols("RFC1316-MIB", "InstancePointer")
( X121Address, ) = mibBuilder.importSymbols("RFC1382-MIB", "X121Address")
( Integer32, MibScalar, MibTable, MibTableRow, MibTableColumn, transmission, TimeTicks, Counter64, NotificationType, iso, Gauge32, MibIdentifier, Bits, Counter32, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Integer32", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "transmission", "TimeTicks", "Counter64", "NotificationType", "iso", "Gauge32", "MibIdentifier", "Bits", "Counter32")
( DisplayString, ) = mibBuilder.importSymbols("SNMPv2-TC", "DisplayString")
miox = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 38))
mioxPle = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 38, 1))
mioxPeer = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 38, 2))
mioxPleTable = MibTable((1, 3, 6, 1, 2, 1, 10, 38, 1, 1), )
if mibBuilder.loadTexts: mioxPleTable.setDescription('This table contains information relative to\n                          an interface to an X.25 Packet Level Entity\n                          (PLE).')
mioxPleEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 38, 1, 1, 1), ).setIndexNames((0, "MIOX25-MIB", "ifIndex"))
if mibBuilder.loadTexts: mioxPleEntry.setDescription('These objects manage the encapsulation of\n                          other protocols within X.25.')
mioxPleMaxCircuits = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 38, 1, 1, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,2147483647))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mioxPleMaxCircuits.setDescription('The maximum number of X.25 circuits that\n                          can be open at one time for this interface.\n                          A value of zero indicates the interface will\n                          not allow any additional circuits (as it may\n                          soon be shutdown).  A value of 2147483647\n                          allows an unlimited number of circuits.')
mioxPleRefusedConnections = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 38, 1, 1, 1, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mioxPleRefusedConnections.setDescription('The number of X.25 calls from a remote\n                          systems to this system that were cleared by\n                          this system.  The interface instance should\n                          identify the X.25 interface the call came in\n                          on.')
mioxPleEnAddrToX121LkupFlrs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 38, 1, 1, 1, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mioxPleEnAddrToX121LkupFlrs.setDescription('The number of times a translation from an\n                          Encapsulated Address to an X.121 address\n                          failed to find a corresponding X.121\n                          address.  Encapsulated addresses can be\n                          looked up in the mioxPeerTable or translated\n                          via an algorithm as for the DDN.  Addresses\n                          that are successfully recognized do not\n                          increment this counter.  Addresses that are\n                          not recognized (reflecting an abnormal\n                          packet delivery condition) increment this\n                          counter.\n\n                          If an address translation fails, it may be\n                          difficult to determine which PLE entry\n                          should count the failure.  In such cases the\n                          first likely entry in this table should be\n                          selected.  Agents should record the failure\n                          even if they are unsure which PLE should be\n                          associated with the failure.')
mioxPleLastFailedEnAddr = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 38, 1, 1, 1, 4), OctetString().subtype(subtypeSpec=ValueSizeConstraint(2,128))).setMaxAccess("readonly")
if mibBuilder.loadTexts: mioxPleLastFailedEnAddr.setDescription('The last Encapsulated address that failed\n                          to find a corresponding X.121 address and\n                          caused mioxPleEnAddrToX121LkupFlrs to be\n                          incremented.  The first octet of this object\n                          contains the encapsulation type, the\n                          remaining octets contain the address of that\n                          type that failed.  Thus for an IP address,\n                          the length will be five octets, the first\n                          octet will contain 204 (hex CC), and the\n                          last four octets will contain the IP\n                          address.  For a snap encapsulation, the\n                          first byte would be 128 (hex 80) and the\n                          rest of the octet string would have the snap\n                          header.')
mioxPleEnAddrToX121LkupFlrTime = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 38, 1, 1, 1, 5), TimeTicks()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mioxPleEnAddrToX121LkupFlrTime.setDescription('The most recent value of sysUpTime when the\n                          translation from an Encapsulated Address to\n                          X.121 address failed to find a corresponding\n                          X.121 address.')
mioxPleX121ToEnAddrLkupFlrs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 38, 1, 1, 1, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mioxPleX121ToEnAddrLkupFlrs.setDescription('The number of times the translation from an\n                          X.121 address to an Encapsulated Address\n                          failed to find a corresponding Encapsulated\n                          Address.  Addresses successfully recognized\n                          by an algorithm do not increment this\n                          counter.  This counter reflects the number\n                          of times call acceptance encountered the\n                          abnormal condition of not recognizing the\n                          peer.')
mioxPleLastFailedX121Address = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 38, 1, 1, 1, 7), X121Address()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mioxPleLastFailedX121Address.setDescription('The last X.121 address that caused\n                          mioxPleX121ToEnAddrLkupFlrs to increase.')
mioxPleX121ToEnAddrLkupFlrTime = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 38, 1, 1, 1, 8), TimeTicks()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mioxPleX121ToEnAddrLkupFlrTime.setDescription('The most recent value of sysUpTime when the\n                          translation from an X.121 address to an\n                          Encapsulated Address failed to find a\n                          corresponding Encapsulated Address.')
mioxPleQbitFailures = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 38, 1, 1, 1, 9), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mioxPleQbitFailures.setDescription('The number of times a connection was closed\n                          because of a Q-bit failure.')
mioxPleQbitFailureRemoteAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 38, 1, 1, 1, 10), X121Address()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mioxPleQbitFailureRemoteAddress.setDescription('The remote address of the most recent\n                          (last) connection that was closed because of\n                          a Q-bit failure.')
mioxPleQbitFailureTime = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 38, 1, 1, 1, 11), TimeTicks()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mioxPleQbitFailureTime.setDescription('The most recent value of sysUpTime when a\n                          connection was closed because of a Q-bit\n                          failure.  This will also be the last time\n                          that mioxPleQbitFailures was incremented.')
mioxPleMinimumOpenTimer = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 38, 1, 1, 1, 12), PositiveInteger()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mioxPleMinimumOpenTimer.setDescription('The minimum time in milliseconds this\n                          interface will keep a connection open before\n                          allowing it to be closed.  A value of zero\n                          indicates no timer.')
mioxPleInactivityTimer = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 38, 1, 1, 1, 13), PositiveInteger().clone(10000)).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mioxPleInactivityTimer.setDescription('The amount of time time in milliseconds\n                          this interface will keep an idle connection\n                          open before closing it.  A value of\n                          2147483647 indicates no timer.')
mioxPleHoldDownTimer = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 38, 1, 1, 1, 14), PositiveInteger()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mioxPleHoldDownTimer.setDescription('The hold down timer in milliseconds.  This\n                          is the minimum amount of time to wait before\n                          trying another call to a host that was\n                          previously unsuccessful.  A value of\n                          2147483647 indicates the host will not be\n                          retried.')
mioxPleCollisionRetryTimer = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 38, 1, 1, 1, 15), PositiveInteger()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mioxPleCollisionRetryTimer.setDescription('The Collision Retry Timer in milliseconds.\n                          The time to delay between call attempts when\n                          the maximum number of circuits is exceeded\n                          in a call attempt.')
mioxPleDefaultPeerId = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 38, 1, 1, 1, 16), InstancePointer()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mioxPleDefaultPeerId.setDescription("This identifies the instance of the index\n                          in the mioxPeerTable for the default\n                          parameters to use with this interface.\n\n                          The entry identified by this object may have\n                          a zero length Encapsulation address and a\n                          zero length X.121 address.\n\n                          These default parameters are used with\n                          connections to hosts that do not have\n                          entries in the mioxPeerTable.  Such\n                          connections occur when using ddn-x25 IP-X.25\n                          address mapping or when accepting\n                          connections from other hosts not in the\n                          mioxPeerTable.\n\n                          The mioxPeerEncTable entry with the same\n                          index as the mioxPeerTable entry specifies\n                          the call encapsulation types this PLE will\n                          accept for peers not in the mioxPeerTable.\n                          If the mioxPeerEncTable doesn't contain any\n                          entries, this PLE will not accept calls from\n                          entries not in the mioxPeerTable.")
mioxPeerTable = MibTable((1, 3, 6, 1, 2, 1, 10, 38, 2, 1), )
if mibBuilder.loadTexts: mioxPeerTable.setDescription('This table contains information about the\n                          possible peers this machine may exchange\n                          packets with.')
mioxPeerEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 38, 2, 1, 1), ).setIndexNames((0, "MIOX25-MIB", "mioxPeerIndex"))
if mibBuilder.loadTexts: mioxPeerEntry.setDescription('Per peer information.')
mioxPeerIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 38, 2, 1, 1, 1), PositiveInteger()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mioxPeerIndex.setDescription('An index value that distinguished one entry\n                          from another.  This index is independent of\n                          any other index.')
mioxPeerStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 38, 2, 1, 1, 2), Integer32().subtype(subtypeSpec=SingleValueConstraint(1, 2, 3, 4, 5, 6,)).clone(namedValues=NamedValues(("valid", 1), ("createRequest", 2), ("underCreation", 3), ("invalid", 4), ("clearCall", 5), ("makeCall", 6),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mioxPeerStatus.setDescription("This reports the status of a peer entry.\n                          A value of valid indicates a normal entry\n                          that is in use by the agent.  A value of\n                          underCreation indicates a newly created\n                          entry which isn't yet in use because the\n                          creating management station is still setting\n                          values.\n\n                          The value of invalid indicates the entry is\n                          no longer in use and the agent is free to\n                          delete the entry at any time.  A management\n                          station is also free to use an entry in the\n                          invalid state.\n\n                          Entries are created by setting a value of\n                          createRequest.  Only non-existent or invalid\n                          entries can be set to createRequest.  Upon\n                          receiving a valid createRequest, the agent\n                          will create an entry in the underCreation\n                          state.  This object can not be set to a\n                          value of underCreation directly, entries can\n                          only be created by setting a value of\n                          createRequest.  Entries that exist in other\n                          than the invalid state can not be set to\n                          createRequest.\n\n                          Entries with a value of underCreation are\n                          not used by the system and the management\n                          station can change the values of other\n                          objects in the table entry.  Management\n                          stations should also remember to configure\n                          values in the mioxPeerEncTable with the same\n                          peer index value as this peer entry.\n\n                          An entry in the underCreation state can be\n                          set to valid or invalid.  Entries in the\n                          underCreation state will stay in that state\n                          until 1) the agent times them out, 2) they\n                          are set to valid, 3) they are set to\n                          invalid.  If an agent notices an entry has\n                          been in the underCreation state for an\n                          abnormally long time, it may decide the\n                          management station has failed and invalidate\n                          the entry.  A prudent agent will understand\n                          that the management station may need to wait\n                          for human input and will allow for that\n                          possibility in its determination of this\n                          abnormally long period.\n\n                          Once a management station has completed all\n                          fields of an entry, it will set a value of\n                          valid.  This causes the entry to be\n                          activated.\n\n                          Entries in the valid state may also be set\n                          to makeCall or clearCall to make or clear\n                          X.25 calls to the peer.  After such a set\n                          request the entry will still be in the valid\n                          state.  Setting a value of makeCall causes\n                          the agent to initiate an X.25 call request\n                          to the peer specified by the entry.  Setting\n                          a value of clearCall causes the agent to\n                          initiate clearing one X.25 call present to\n                          the peer.  Each set request will initiate\n                          another call or clear request (up to the\n                          maximum allowed); this means that management\n                          stations that fail to get a response to a\n                          set request should query to see if a call\n                          was in fact placed or cleared before\n                          retrying the request.  Entries not in the\n                          valid state can not be set to makeCall or\n                          clearCall.\n\n                          The values of makeCall and clearCall provide\n                          for circuit control on devices which perform\n                          Ethernet Bridging using static circuit\n                          assignment without address recognition;\n                          other devices which dynamically place calls\n                          based on destination addresses may reject\n                          such requests.\n\n                          An agent that (re)creates a new entry\n                          because of a set with createRequest, should\n                          also (re)create a mioxPeerEncTable entry\n                          with a mioxPeerEncIndex of 1, and a\n                          mioxPeerEncType of 204 (hex CC).")
mioxPeerMaxCircuits = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 38, 2, 1, 1, 3), PositiveInteger().clone(1)).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mioxPeerMaxCircuits.setDescription('The maximum number of X.25 circuits allowed\n                          to this peer.')
mioxPeerIfIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 38, 2, 1, 1, 4), PositiveInteger().clone(1)).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mioxPeerIfIndex.setDescription('The value of the ifIndex object for the\n                          interface to X.25 to use to call the peer.')
mioxPeerConnectSeconds = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 38, 2, 1, 1, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mioxPeerConnectSeconds.setDescription('The number of seconds a call to this peer\n                          was active.  This counter will be\n                          incremented by one for every second a\n                          connection to a peer was open.  If two calls\n                          are open at the same time, one second of\n                          elapsed real time will results in two\n                          seconds of connect time.')
mioxPeerX25CallParamId = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 38, 2, 1, 1, 6), InstancePointer()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mioxPeerX25CallParamId.setDescription('The instance of the index object in the\n                          x25CallParmTable from RFC 1382 for the X.25\n                          call parameters used to communicate with the\n                          remote host.  The well known value {0 0}\n                          indicates no call parameters specified.')
mioxPeerEnAddr = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 38, 2, 1, 1, 7), OctetString().subtype(subtypeSpec=ValueSizeConstraint(0,128)).clone(hexValue="")).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mioxPeerEnAddr.setDescription('The Encapsulation address of the remote\n                          host mapped by this table entry.  A length\n                          of zero indicates the remote IP address is\n                          unknown or unspecified for use as a PLE\n                          default.\n\n                          The first octet of this object contains the\n                          encapsulation type, the remaining octets\n                          contain an address of that type.  Thus for\n                          an IP address, the length will be five\n                          octets, the first octet will contain 204\n                          (hex CC), and the last four octets will\n                          contain the IP address.  For a snap\n                          encapsulation, the first byte would be 128\n                          (hex 80) and the rest of the octet string\n                          would have the snap header.')
mioxPeerX121Address = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 38, 2, 1, 1, 8), X121Address().clone(hexValue="")).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mioxPeerX121Address.setDescription('The X.25 address of the remote host mapped\n                          by this table entry.  A zero length string\n                          indicates the X.25 address is unspecified\n                          for use as the PLE default.')
mioxPeerX25CircuitId = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 38, 2, 1, 1, 9), InstancePointer()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mioxPeerX25CircuitId.setDescription('This object identifies the instance of the\n                          index for the X.25 circuit open to the peer\n                          mapped by this table entry.  The well known\n                          value {0 0} indicates no connection\n                          currently active.  For multiple connections,\n                          this identifies the index of a multiplexing\n                          table entry for the connections.  This can\n                          only be written to configure use of PVCs\n                          which means the identified circuit table\n                          entry for a write must be a PVC.')
mioxPeerDescr = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 38, 2, 1, 1, 10), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,255)).clone(hexValue="")).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mioxPeerDescr.setDescription('This object returns any identification\n                          information about the peer.  An agent may\n                          supply the comment information found in the\n                          configuration file entry for this peer.  A\n                          zero length string indicates no information\n                          available.')
mioxPeerEncTable = MibTable((1, 3, 6, 1, 2, 1, 10, 38, 2, 2), )
if mibBuilder.loadTexts: mioxPeerEncTable.setDescription("This table contains the list of\n                          encapsulations used to communicate with a\n                          peer.  This table has two indexes, the first\n                          identifies the peer, the second\n                          distinguishes encapsulation types.\n\n                          The first index identifies the corresponding\n                          entry in the mioxPeerTable.  The second\n                          index gives the priority of the different\n                          encapsulations.\n\n                          The encapsulation types are ordered in\n                          priority order.  For calling a peer, the\n                          first entry (mioxPeerEncIndex of 1) is tried\n                          first.  If the call doesn't succeed because\n                          the remote host clears the call due to\n                          incompatible call user data, the next entry\n                          in the list is tried.  Each entry is tried\n                          until the list is exhausted.\n\n                          For answering a call, the encapsulation type\n                          requested by the peer must be found the list\n                          or the call will be refused.  If there are\n                          no entries in this table for a peer, all\n                          call requests from the peer will be refused.\n\n                          Objects in this table can only be set when\n                          the mioxPeerStatus object with the same\n                          index has a value of underCreation.  When\n                          that status object is set to invalid and\n                          deleted, the entry in this table with that\n                          peer index must also be deleted.")
mioxPeerEncEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 38, 2, 2, 1), ).setIndexNames((0, "MIOX25-MIB", "mioxPeerIndex"), (0, "MIOX25-MIB", "mioxPeerEncIndex"))
if mibBuilder.loadTexts: mioxPeerEncEntry.setDescription('Per connection information.')
mioxPeerEncIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 38, 2, 2, 1, 1), PositiveInteger()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mioxPeerEncIndex.setDescription('The second index in the table which\n                          distinguishes different encapsulation\n                          types.')
mioxPeerEncType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 38, 2, 2, 1, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,256))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mioxPeerEncType.setDescription('The value of the encapsulation type.  For\n                          IP encapsulation this will have a value of\n                          204 (hex CC).  For SNAP encapsulated\n                          packets, this will have a value of 128 (hex\n                          80).  For CLNP, ISO 8473, this will have a\n                          value of 129 (hex 81).  For ES-ES, ISO 9542,\n                          this will have a value of 130 (hex 82).  A\n                          value of 197 (hex C5) identifies the Blacker\n                          X.25 encapsulation.  A value of 0,\n                          identifies the Null encapsulation.\n\n                          This value can only be written when the\n                          mioxPeerStatus object with the same\n                          mioxPeerIndex has a value of underCreation.\n                          Setting this object to a value of 256\n                          deletes the entry.  When deleting an entry,\n                          all other entries in the mioxPeerEncTable\n                          with the same mioxPeerIndex and with an\n                          mioxPeerEncIndex higher then the deleted\n                          entry, will all have their mioxPeerEncIndex\n                          values decremented by one.')
mibBuilder.exportSymbols("MIOX25-MIB", mioxPleX121ToEnAddrLkupFlrs=mioxPleX121ToEnAddrLkupFlrs, mioxPeerX25CallParamId=mioxPeerX25CallParamId, mioxPeerDescr=mioxPeerDescr, mioxPeerIfIndex=mioxPeerIfIndex, mioxPeerEncEntry=mioxPeerEncEntry, mioxPle=mioxPle, mioxPeerMaxCircuits=mioxPeerMaxCircuits, mioxPeerStatus=mioxPeerStatus, mioxPleMaxCircuits=mioxPleMaxCircuits, mioxPeerTable=mioxPeerTable, mioxPleLastFailedX121Address=mioxPleLastFailedX121Address, mioxPleMinimumOpenTimer=mioxPleMinimumOpenTimer, mioxPeerEncType=mioxPeerEncType, mioxPleQbitFailures=mioxPleQbitFailures, mioxPleEnAddrToX121LkupFlrTime=mioxPleEnAddrToX121LkupFlrTime, mioxPeer=mioxPeer, mioxPeerEntry=mioxPeerEntry, mioxPleDefaultPeerId=mioxPleDefaultPeerId, mioxPeerEnAddr=mioxPeerEnAddr, mioxPeerX121Address=mioxPeerX121Address, mioxPleQbitFailureTime=mioxPleQbitFailureTime, mioxPeerConnectSeconds=mioxPeerConnectSeconds, mioxPeerEncTable=mioxPeerEncTable, mioxPleLastFailedEnAddr=mioxPleLastFailedEnAddr, mioxPleEntry=mioxPleEntry, mioxPeerIndex=mioxPeerIndex, mioxPleCollisionRetryTimer=mioxPleCollisionRetryTimer, mioxPleHoldDownTimer=mioxPleHoldDownTimer, mioxPleX121ToEnAddrLkupFlrTime=mioxPleX121ToEnAddrLkupFlrTime, miox=miox, mioxPleTable=mioxPleTable, mioxPleRefusedConnections=mioxPleRefusedConnections, mioxPleQbitFailureRemoteAddress=mioxPleQbitFailureRemoteAddress, mioxPeerEncIndex=mioxPeerEncIndex, mioxPleEnAddrToX121LkupFlrs=mioxPleEnAddrToX121LkupFlrs, mioxPeerX25CircuitId=mioxPeerX25CircuitId, mioxPleInactivityTimer=mioxPleInactivityTimer)



#
# PySNMP MIB module TOKENRING-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/TOKENRING-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:31:49 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( Integer, OctetString, ObjectIdentifier, ) = mibBuilder.importSymbols("ASN1", "Integer", "OctetString", "ObjectIdentifier")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( SingleValueConstraint, ValueSizeConstraint, ConstraintsUnion, ValueRangeConstraint, ConstraintsIntersection, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "SingleValueConstraint", "ValueSizeConstraint", "ConstraintsUnion", "ValueRangeConstraint", "ConstraintsIntersection")
( NotificationGroup, ObjectGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup", "ObjectGroup", "ModuleCompliance")
( iso, IpAddress, ModuleIdentity, ObjectIdentity, MibScalar, MibTable, MibTableRow, MibTableColumn, MibIdentifier, NotificationType, Integer32, TimeTicks, Bits, Counter64, Gauge32, Unsigned32, transmission, Counter32, ) = mibBuilder.importSymbols("SNMPv2-SMI", "iso", "IpAddress", "ModuleIdentity", "ObjectIdentity", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "MibIdentifier", "NotificationType", "Integer32", "TimeTicks", "Bits", "Counter64", "Gauge32", "Unsigned32", "transmission", "Counter32")
( TextualConvention, MacAddress, DisplayString, TimeStamp, ) = mibBuilder.importSymbols("SNMPv2-TC", "TextualConvention", "MacAddress", "DisplayString", "TimeStamp")
dot5 = ModuleIdentity((1, 3, 6, 1, 2, 1, 10, 9))
if mibBuilder.loadTexts: dot5.setLastUpdated('9410231150Z')
if mibBuilder.loadTexts: dot5.setOrganization('IETF Interfaces MIB Working Group')
if mibBuilder.loadTexts: dot5.setContactInfo('        Keith McCloghrie\n\n             Postal: cisco Systems, Inc.\n                     170 West Tasman Drive,\n                     San Jose, CA 95134-1706\n\n                     US\n\n              Phone: +1 408 526 5260\n              EMail: kzm@cisco.com')
if mibBuilder.loadTexts: dot5.setDescription('The MIB module for IEEE Token Ring entities.')
dot5Table = MibTable((1, 3, 6, 1, 2, 1, 10, 9, 1), )
if mibBuilder.loadTexts: dot5Table.setDescription('This table contains Token Ring interface\n            parameters and state variables, one entry\n            per 802.5 interface.')
dot5Entry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 9, 1, 1), ).setIndexNames((0, "TOKENRING-MIB", "dot5IfIndex"))
if mibBuilder.loadTexts: dot5Entry.setDescription('A list of Token Ring status and parameter\n             values for an 802.5 interface.')
dot5IfIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 9, 1, 1, 1), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot5IfIndex.setDescription('The value of this object identifies the\n             802.5 interface for which this entry\n             contains management information.  The\n             value of this object for a particular\n             interface has the same value as the\n             ifIndex object, defined in MIB-II for\n             the same interface.')
dot5Commands = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 9, 1, 1, 2), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))).clone(namedValues=NamedValues(("noop", 1), ("open", 2), ("reset", 3), ("close", 4),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dot5Commands.setDescription("When this object is set to the value of\n             open(2), the station should go into the\n             open state.  The progress and success of\n             the open is given by the values of the\n             objects dot5RingState and\n             dot5RingOpenStatus.\n                 When this object is set to the value\n             of reset(3), then the station should do\n             a reset.  On a reset, all MIB counters\n             should retain their values, if possible.\n             Other side affects are dependent on the\n             hardware chip set.\n                 When this object is set to the value\n             of close(4), the station should go into\n             the stopped state by removing itself\n             from the ring.\n                 Setting this object to a value of\n             noop(1) has no effect.\n                 When read, this object always has a\n             value of noop(1).\n                 The open(2) and close(4) values\n             correspond to the up(1) and down(2) values\n             of MIB-II's ifAdminStatus and ifOperStatus,\n             i.e., the setting of ifAdminStatus and\n\n             dot5Commands affects the values of both\n             dot5Commands and ifOperStatus.")
dot5RingStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 9, 1, 1, 3), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,262143))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot5RingStatus.setDescription("The current interface status which can\n            be used to diagnose fluctuating problems\n            that can occur on token rings, after a\n            station has successfully been added to\n            the ring.\n               Before an open is completed, this\n            object has the value for the 'no status'\n            condition.  The dot5RingState and\n            dot5RingOpenStatus objects provide for\n            debugging problems when the station\n            can not even enter the ring.\n                The object's value is a sum of\n            values, one for each currently applicable\n            condition.  The following values are\n            defined for various conditions:\n\n                    0 = No Problems detected\n                   32 = Ring Recovery\n                   64 = Single Station\n                  256 = Remove Received\n                  512 = reserved\n                 1024 = Auto-Removal Error\n                 2048 = Lobe Wire Fault\n                 4096 = Transmit Beacon\n                 8192 = Soft Error\n                16384 = Hard Error\n                32768 = Signal Loss\n               131072 = no status, open not completed.")
dot5RingState = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 9, 1, 1, 4), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6,))).clone(namedValues=NamedValues(("opened", 1), ("closed", 2), ("opening", 3), ("closing", 4), ("openFailure", 5), ("ringFailure", 6),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot5RingState.setDescription('The current interface state with respect\n            to entering or leaving the ring.')
dot5RingOpenStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 9, 1, 1, 5), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11,))).clone(namedValues=NamedValues(("noOpen", 1), ("badParam", 2), ("lobeFailed", 3), ("signalLoss", 4), ("insertionTimeout", 5), ("ringFailed", 6), ("beaconing", 7), ("duplicateMAC", 8), ("requestFailed", 9), ("removeReceived", 10), ("open", 11),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot5RingOpenStatus.setDescription("This object indicates the success, or the\n            reason for failure, of the station's most\n            recent attempt to enter the ring.")
dot5RingSpeed = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 9, 1, 1, 6), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))).clone(namedValues=NamedValues(("unknown", 1), ("oneMegabit", 2), ("fourMegabit", 3), ("sixteenMegabit", 4),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dot5RingSpeed.setDescription("The ring-speed at the next insertion into\n            the ring.  Note that this may or may not be\n            different to the current ring-speed which is\n            given by MIB-II's ifSpeed.  For interfaces\n            which do not support changing ring-speed,\n            dot5RingSpeed can only be set to its current\n            value.  When dot5RingSpeed has the value\n            unknown(1), the ring's actual ring-speed is\n            to be used.")
dot5UpStream = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 9, 1, 1, 7), MacAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot5UpStream.setDescription('The MAC-address of the up stream neighbor\n             station in the ring.')
dot5ActMonParticipate = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 9, 1, 1, 8), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("true", 1), ("false", 2),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dot5ActMonParticipate.setDescription('If this object has a value of true(1) then\n            this interface will participate in the\n            active monitor selection process.  If the\n            value is false(2) then it will not.\n            Setting this object does not take effect\n            until the next Active Monitor election, and\n            might not take effect until the next time\n            the interface is opened.')
dot5Functional = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 9, 1, 1, 9), MacAddress()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dot5Functional.setDescription('The bit mask of all Token Ring functional\n            addresses for which this interface will\n            accept frames.')
dot5LastBeaconSent = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 9, 1, 1, 10), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot5LastBeaconSent.setDescription("The value of MIB-II's sysUpTime object at which\n            the local system last transmitted a Beacon frame\n            on this interface.")
dot5StatsTable = MibTable((1, 3, 6, 1, 2, 1, 10, 9, 2), )
if mibBuilder.loadTexts: dot5StatsTable.setDescription("A table containing Token Ring statistics,\n            one entry per 802.5 interface.\n                All the statistics are defined using\n            the syntax Counter32 as 32-bit wrap around\n            counters.  Thus, if an interface's\n            hardware maintains these statistics in\n            16-bit counters, then the agent must read\n            the hardware's counters frequently enough\n            to prevent loss of significance, in order\n            to maintain 32-bit counters in software.")
dot5StatsEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 9, 2, 1), ).setIndexNames((0, "TOKENRING-MIB", "dot5StatsIfIndex"))
if mibBuilder.loadTexts: dot5StatsEntry.setDescription('An entry contains the 802.5 statistics\n             for a particular interface.')
dot5StatsIfIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 9, 2, 1, 1), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot5StatsIfIndex.setDescription("The value of this object identifies the\n            802.5 interface for which this entry\n            contains management information.  The\n            value of this object for a particular\n            interface has the same value as MIB-II's\n            ifIndex object for the same interface.")
dot5StatsLineErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 9, 2, 1, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot5StatsLineErrors.setDescription('This counter is incremented when a frame\n            or token is copied or repeated by a\n            station, the E bit is zero in the frame\n            or token and one of the following\n            conditions exists: 1) there is a\n            non-data bit (J or K bit) between the SD\n            and the ED of the frame or token, or\n            2) there is an FCS error in the frame.')
dot5StatsBurstErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 9, 2, 1, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot5StatsBurstErrors.setDescription('This counter is incremented when a station\n            detects the absence of transitions for five\n            half-bit timers (burst-five error).')
dot5StatsACErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 9, 2, 1, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot5StatsACErrors.setDescription('This counter is incremented when a station\n            receives an AMP or SMP frame in which A is\n            equal to C is equal to 0, and then receives\n            another SMP frame with A is equal to C is\n            equal to 0 without first receiving an AMP\n            frame. It denotes a station that cannot set\n            the AC bits properly.')
dot5StatsAbortTransErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 9, 2, 1, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot5StatsAbortTransErrors.setDescription('This counter is incremented when a station\n            transmits an abort delimiter while\n            transmitting.')
dot5StatsInternalErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 9, 2, 1, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot5StatsInternalErrors.setDescription('This counter is incremented when a station\n            recognizes an internal error.')
dot5StatsLostFrameErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 9, 2, 1, 7), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot5StatsLostFrameErrors.setDescription('This counter is incremented when a station\n            is transmitting and its TRR timer expires.\n            This condition denotes a condition where a\n            transmitting station in strip mode does not\n            receive the trailer of the frame before the\n            TRR timer goes off.')
dot5StatsReceiveCongestions = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 9, 2, 1, 8), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot5StatsReceiveCongestions.setDescription('This counter is incremented when a station\n            recognizes a frame addressed to its\n            specific address, but has no available\n            buffer space indicating that the station\n            is congested.')
dot5StatsFrameCopiedErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 9, 2, 1, 9), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot5StatsFrameCopiedErrors.setDescription('This counter is incremented when a station\n            recognizes a frame addressed to its\n            specific address and detects that the FS\n            field A bits are set to 1 indicating a\n            possible line hit or duplicate address.')
dot5StatsTokenErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 9, 2, 1, 10), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot5StatsTokenErrors.setDescription('This counter is incremented when a station\n            acting as the active monitor recognizes an\n            error condition that needs a token\n            transmitted.')
dot5StatsSoftErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 9, 2, 1, 11), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot5StatsSoftErrors.setDescription('The number of Soft Errors the interface\n            has detected. It directly corresponds to\n            the number of Report Error MAC frames\n            that this interface has transmitted.\n            Soft Errors are those which are\n            recoverable by the MAC layer protocols.')
dot5StatsHardErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 9, 2, 1, 12), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot5StatsHardErrors.setDescription('The number of times this interface has\n            detected an immediately recoverable\n            fatal error.  It denotes the number of\n            times this interface is either\n            transmitting or receiving beacon MAC\n            frames.')
dot5StatsSignalLoss = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 9, 2, 1, 13), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot5StatsSignalLoss.setDescription('The number of times this interface has\n            detected the loss of signal condition from\n            the ring.')
dot5StatsTransmitBeacons = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 9, 2, 1, 14), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot5StatsTransmitBeacons.setDescription('The number of times this interface has\n            transmitted a beacon frame.')
dot5StatsRecoverys = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 9, 2, 1, 15), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot5StatsRecoverys.setDescription('The number of Claim Token MAC frames\n            received or transmitted after the interface\n            has received a Ring Purge MAC frame.  This\n            counter signifies the number of times the\n            ring has been purged and is being recovered\n            back into a normal operating state.')
dot5StatsLobeWires = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 9, 2, 1, 16), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot5StatsLobeWires.setDescription('The number of times the interface has\n            detected an open or short circuit in the\n            lobe data path.  The adapter will be closed\n            and dot5RingState will signify this\n            condition.')
dot5StatsRemoves = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 9, 2, 1, 17), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot5StatsRemoves.setDescription('The number of times the interface has\n            received a Remove Ring Station MAC frame\n            request.  When this frame is received\n            the interface will enter the close state\n            and dot5RingState will signify this\n            condition.')
dot5StatsSingles = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 9, 2, 1, 18), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot5StatsSingles.setDescription('The number of times the interface has\n            sensed that it is the only station on the\n            ring.  This will happen if the interface\n            is the first one up on a ring, or if\n            there is a hardware problem.')
dot5StatsFreqErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 9, 2, 1, 19), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot5StatsFreqErrors.setDescription('The number of times the interface has\n            detected that the frequency of the\n            incoming signal differs from the expected\n            frequency by more than that specified by\n            the IEEE 802.5 standard.')
dot5TimerTable = MibTable((1, 3, 6, 1, 2, 1, 10, 9, 5), )
if mibBuilder.loadTexts: dot5TimerTable.setDescription('This table contains Token Ring interface\n            timer values, one entry per 802.5\n            interface.')
dot5TimerEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 9, 5, 1), ).setIndexNames((0, "TOKENRING-MIB", "dot5TimerIfIndex"))
if mibBuilder.loadTexts: dot5TimerEntry.setDescription('A list of Token Ring timer values for an\n            802.5 interface.')
dot5TimerIfIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 9, 5, 1, 1), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot5TimerIfIndex.setDescription("The value of this object identifies the\n             802.5 interface for which this entry\n             contains timer values.  The value of\n\n             this object for a particular interface\n             has the same value as MIB-II's ifIndex\n             object for the same interface.")
dot5TimerReturnRepeat = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 9, 5, 1, 2), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot5TimerReturnRepeat.setDescription('The time-out value used to ensure the\n            interface will return to Repeat State, in\n            units of 100 micro-seconds.  The value\n            should be greater than the maximum ring\n            latency.')
dot5TimerHolding = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 9, 5, 1, 3), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot5TimerHolding.setDescription('Maximum period of time a station is\n            permitted to transmit frames after capturing\n            a token, in units of 100 micro-seconds.')
dot5TimerQueuePDU = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 9, 5, 1, 4), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot5TimerQueuePDU.setDescription('The time-out value for enqueuing of an SMP\n            PDU after reception of an AMP or SMP\n            frame in which the A and C bits were\n            equal to 0, in units of 100\n            micro-seconds.')
dot5TimerValidTransmit = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 9, 5, 1, 5), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot5TimerValidTransmit.setDescription('The time-out value used by the active\n            monitor to detect the absence of valid\n            transmissions, in units of 100\n            micro-seconds.')
dot5TimerNoToken = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 9, 5, 1, 6), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot5TimerNoToken.setDescription('The time-out value used to recover from\n            various-related error situations.\n            If N is the maximum number of stations on\n            the ring, the value of this timer is\n            normally:\n            dot5TimerReturnRepeat + N*dot5TimerHolding.')
dot5TimerActiveMon = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 9, 5, 1, 7), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot5TimerActiveMon.setDescription('The time-out value used by the active\n            monitor to stimulate the enqueuing of an\n            AMP PDU for transmission, in units of\n            100 micro-seconds.')
dot5TimerStandbyMon = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 9, 5, 1, 8), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot5TimerStandbyMon.setDescription('The time-out value used by the stand-by\n            monitors to ensure that there is an active\n            monitor on the ring and to detect a\n            continuous stream of tokens, in units of\n            100 micro-seconds.')
dot5TimerErrorReport = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 9, 5, 1, 9), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot5TimerErrorReport.setDescription('The time-out value which determines how\n            often a station shall send a Report Error\n            MAC frame to report its error counters,\n            in units of 100 micro-seconds.')
dot5TimerBeaconTransmit = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 9, 5, 1, 10), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot5TimerBeaconTransmit.setDescription('The time-out value which determines how\n            long a station shall remain in the state\n            of transmitting Beacon frames before\n            entering the Bypass state, in units of\n            100 micro-seconds.')
dot5TimerBeaconReceive = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 9, 5, 1, 11), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot5TimerBeaconReceive.setDescription('The time-out value which determines how\n            long a station shall receive Beacon\n            frames from its downstream neighbor\n            before entering the Bypass state, in\n            units of 100 micro-seconds.')
dot5Tests = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 9, 3))
dot5TestInsertFunc = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 9, 3, 1))
if mibBuilder.loadTexts: dot5TestInsertFunc.setDescription("Invoking this test causes the station to test the insert\n        ring logic of the hardware if the station's lobe media\n        cable is connected to a wiring concentrator.  Note that\n        this command inserts the station into the network, and\n        thus, could cause problems if the station is connected\n        to a operational network.")
dot5TestFullDuplexLoopBack = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 9, 3, 2))
if mibBuilder.loadTexts: dot5TestFullDuplexLoopBack.setDescription("Invoking this test on a 802.5 interface causes the\n        interface to check the path from memory through the\n        chip set's internal logic and back to memory, thus\n        checking the proper functioning of the system's\n        interface to the chip set.")
dot5ChipSets = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 9, 4))
dot5ChipSetIBM16 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 9, 4, 1))
if mibBuilder.loadTexts: dot5ChipSetIBM16.setDescription("IBM's 16/4 Mbs chip set.")
dot5ChipSetTItms380 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 9, 4, 2))
if mibBuilder.loadTexts: dot5ChipSetTItms380.setDescription("Texas Instruments' TMS 380 4Mbs chip-set")
dot5ChipSetTItms380c16 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 9, 4, 3))
if mibBuilder.loadTexts: dot5ChipSetTItms380c16.setDescription("Texas Instruments' TMS 380C16 16/4 Mbs chip-set")
dot5Conformance = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 9, 6))
dot5Groups = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 9, 6, 1))
dot5Compliances = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 9, 6, 2))
dot5Compliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 10, 9, 6, 2, 1)).setObjects(*(("TOKENRING-MIB", "dot5StateGroup"), ("TOKENRING-MIB", "dot5StatsGroup"),))
if mibBuilder.loadTexts: dot5Compliance.setDescription('The compliance statement for SNMPv2 entities\n        which implement the IEEE 802.5 MIB.')
dot5StateGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 9, 6, 1, 1)).setObjects(*(("TOKENRING-MIB", "dot5Commands"), ("TOKENRING-MIB", "dot5RingStatus"), ("TOKENRING-MIB", "dot5RingState"), ("TOKENRING-MIB", "dot5RingOpenStatus"), ("TOKENRING-MIB", "dot5RingSpeed"), ("TOKENRING-MIB", "dot5UpStream"), ("TOKENRING-MIB", "dot5ActMonParticipate"), ("TOKENRING-MIB", "dot5Functional"), ("TOKENRING-MIB", "dot5LastBeaconSent"),))
if mibBuilder.loadTexts: dot5StateGroup.setDescription('A collection of objects providing state information\n        and parameters for IEEE 802.5 interfaces.')
dot5StatsGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 9, 6, 1, 2)).setObjects(*(("TOKENRING-MIB", "dot5StatsLineErrors"), ("TOKENRING-MIB", "dot5StatsBurstErrors"), ("TOKENRING-MIB", "dot5StatsACErrors"), ("TOKENRING-MIB", "dot5StatsAbortTransErrors"), ("TOKENRING-MIB", "dot5StatsInternalErrors"), ("TOKENRING-MIB", "dot5StatsLostFrameErrors"), ("TOKENRING-MIB", "dot5StatsReceiveCongestions"), ("TOKENRING-MIB", "dot5StatsFrameCopiedErrors"), ("TOKENRING-MIB", "dot5StatsTokenErrors"), ("TOKENRING-MIB", "dot5StatsSoftErrors"), ("TOKENRING-MIB", "dot5StatsHardErrors"), ("TOKENRING-MIB", "dot5StatsSignalLoss"), ("TOKENRING-MIB", "dot5StatsTransmitBeacons"), ("TOKENRING-MIB", "dot5StatsRecoverys"), ("TOKENRING-MIB", "dot5StatsLobeWires"), ("TOKENRING-MIB", "dot5StatsRemoves"), ("TOKENRING-MIB", "dot5StatsSingles"), ("TOKENRING-MIB", "dot5StatsFreqErrors"),))
if mibBuilder.loadTexts: dot5StatsGroup.setDescription('A collection of objects providing statistics for\n        IEEE 802.5 interfaces.')
mibBuilder.exportSymbols("TOKENRING-MIB", dot5=dot5, dot5StatsACErrors=dot5StatsACErrors, dot5StatsTransmitBeacons=dot5StatsTransmitBeacons, dot5RingOpenStatus=dot5RingOpenStatus, dot5StateGroup=dot5StateGroup, dot5Groups=dot5Groups, dot5Compliances=dot5Compliances, dot5TestInsertFunc=dot5TestInsertFunc, dot5Functional=dot5Functional, dot5StatsBurstErrors=dot5StatsBurstErrors, dot5Table=dot5Table, dot5TimerBeaconReceive=dot5TimerBeaconReceive, dot5StatsHardErrors=dot5StatsHardErrors, dot5TimerValidTransmit=dot5TimerValidTransmit, dot5StatsSingles=dot5StatsSingles, dot5RingState=dot5RingState, dot5TimerStandbyMon=dot5TimerStandbyMon, dot5ChipSets=dot5ChipSets, dot5StatsRecoverys=dot5StatsRecoverys, dot5TestFullDuplexLoopBack=dot5TestFullDuplexLoopBack, dot5ChipSetTItms380c16=dot5ChipSetTItms380c16, dot5StatsLostFrameErrors=dot5StatsLostFrameErrors, dot5Commands=dot5Commands, dot5TimerTable=dot5TimerTable, dot5ChipSetIBM16=dot5ChipSetIBM16, dot5LastBeaconSent=dot5LastBeaconSent, dot5StatsAbortTransErrors=dot5StatsAbortTransErrors, dot5StatsTokenErrors=dot5StatsTokenErrors, dot5StatsSoftErrors=dot5StatsSoftErrors, dot5Tests=dot5Tests, dot5StatsIfIndex=dot5StatsIfIndex, dot5Entry=dot5Entry, dot5StatsRemoves=dot5StatsRemoves, dot5TimerBeaconTransmit=dot5TimerBeaconTransmit, dot5StatsInternalErrors=dot5StatsInternalErrors, dot5StatsLineErrors=dot5StatsLineErrors, dot5StatsReceiveCongestions=dot5StatsReceiveCongestions, dot5TimerNoToken=dot5TimerNoToken, dot5RingSpeed=dot5RingSpeed, dot5TimerErrorReport=dot5TimerErrorReport, dot5TimerReturnRepeat=dot5TimerReturnRepeat, dot5StatsTable=dot5StatsTable, dot5StatsSignalLoss=dot5StatsSignalLoss, dot5ActMonParticipate=dot5ActMonParticipate, dot5TimerEntry=dot5TimerEntry, PYSNMP_MODULE_ID=dot5, dot5StatsEntry=dot5StatsEntry, dot5TimerHolding=dot5TimerHolding, dot5TimerQueuePDU=dot5TimerQueuePDU, dot5StatsGroup=dot5StatsGroup, dot5TimerIfIndex=dot5TimerIfIndex, dot5TimerActiveMon=dot5TimerActiveMon, dot5UpStream=dot5UpStream, dot5StatsFrameCopiedErrors=dot5StatsFrameCopiedErrors, dot5RingStatus=dot5RingStatus, dot5StatsLobeWires=dot5StatsLobeWires, dot5StatsFreqErrors=dot5StatsFreqErrors, dot5ChipSetTItms380=dot5ChipSetTItms380, dot5Conformance=dot5Conformance, dot5IfIndex=dot5IfIndex, dot5Compliance=dot5Compliance)



#
# PySNMP MIB module VPN-TC-STD-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/VPN-TC-STD-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:20:45 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( OctetString, ObjectIdentifier, Integer, ) = mibBuilder.importSymbols("ASN1", "OctetString", "ObjectIdentifier", "Integer")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ValueRangeConstraint, SingleValueConstraint, ConstraintsUnion, ConstraintsIntersection, ValueSizeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueRangeConstraint", "SingleValueConstraint", "ConstraintsUnion", "ConstraintsIntersection", "ValueSizeConstraint")
( NotificationGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup", "ModuleCompliance")
( iso, Counter64, IpAddress, Integer32, Bits, NotificationType, ObjectIdentity, Unsigned32, Gauge32, mib_2, MibScalar, MibTable, MibTableRow, MibTableColumn, ModuleIdentity, MibIdentifier, TimeTicks, Counter32, ) = mibBuilder.importSymbols("SNMPv2-SMI", "iso", "Counter64", "IpAddress", "Integer32", "Bits", "NotificationType", "ObjectIdentity", "Unsigned32", "Gauge32", "mib-2", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "ModuleIdentity", "MibIdentifier", "TimeTicks", "Counter32")
( DisplayString, TextualConvention, ) = mibBuilder.importSymbols("SNMPv2-TC", "DisplayString", "TextualConvention")
vpnTcMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 129)).setRevisions(("2005-11-15 00:00",))
if mibBuilder.loadTexts: vpnTcMIB.setLastUpdated('200511150000Z')
if mibBuilder.loadTexts: vpnTcMIB.setOrganization('Layer 3 Virtual Private Networks (L3VPN) Working Group.')
if mibBuilder.loadTexts: vpnTcMIB.setContactInfo('Benson Schliesser\n         bensons@savvis.net\n\n         Thomas D. Nadeau\n         tnadeau@cisco.com\n\n         This TC MIB is a product of the PPVPN\n         http://www.ietf.org/html.charters/ppvpn-charter.html\n         and subsequently the L3VPN\n         http://www.ietf.org/html.charters/l3vpn-charter.html\n         working groups.\n\n         Comments and discussion should be directed to\n         l3vpn@ietf.org')
if mibBuilder.loadTexts: vpnTcMIB.setDescription('This MIB contains TCs for VPNs.\n\n         Copyright (C) The Internet Society (2005).  This version\n         of this MIB module is part of RFC 4265;  see the RFC\n         itself for full legal notices.')
class VPNId(OctetString, TextualConvention):
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(7,7)
    fixedLength = 7

class VPNIdOrZero(OctetString, TextualConvention):
    subtypeSpec = OctetString.subtypeSpec+ConstraintsUnion(ValueSizeConstraint(0,0),ValueSizeConstraint(7,7),)
mibBuilder.exportSymbols("VPN-TC-STD-MIB", VPNId=VPNId, VPNIdOrZero=VPNIdOrZero, vpnTcMIB=vpnTcMIB, PYSNMP_MODULE_ID=vpnTcMIB)
